// SPDX-FileCopyrightText: 2019 - 2026 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

//#include "test_cweekdaybackgrounditem.h"

//test_CWeekDayBackgroundItem::test_CWeekDayBackgroundItem()
//{
//}

//void test_CWeekDayBackgroundItem::SetUp()
//{
//    m_weekItem = new CWeekDayBackgroundItem();
//}

//void test_CWeekDayBackgroundItem::TearDown()
//{
//    delete m_weekItem;
//    m_weekItem = nullptr;
//}

////showFocus
//TEST_F(test_CWeekDayBackgroundItem, showFocus)
//{
//    m_weekItem->setShowFocus(true);
//    ASSERT_TRUE(m_weekItem->showFocus());
//    m_weekItem->setShowFocus(false);
//    ASSERT_FALSE(m_weekItem->showFocus());
//}

////setItemFocus
//TEST_F(test_CWeekDayBackgroundItem, setItemFocus)
//{
//    m_weekItem->setItemFocus(true);
//}

////hasNextSubItem
//TEST_F(test_CWeekDayBackgroundItem, hasNextSubItem)
//{
//    bool hasNextSub;
//    hasNextSub = m_weekItem->hasNextSubItem();
//    ASSERT_FALSE(hasNextSub);
//}

////drawDividingLine
//TEST_F(test_CWeekDayBackgroundItem, drawDividingLine)
//{
//    m_weekItem->setDrawDividingLine(false);
//    ASSERT_FALSE(m_weekItem->drawDividingLine());
//    m_weekItem->setDrawDividingLine(true);
//    ASSERT_TRUE(m_weekItem->drawDividingLine());
//}
